==> python-gvm-21.5.2.tar.gz: python-gvm-21.5.2/tests/protocols/gmpv208/entities/report_formats/test_delete_report_format.py <==
# -*- coding: utf-8 -*-
# Copyright (C) 2018-2021 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import GvmError
from gvm.protocols.gmpv208.entities.report_formats import (
    ReportFormatType,
    get_report_format_id_from_string,
)


class GmpDeleteReportFormatTestMixin:
    def test_delete(self):
        self.gmp.delete_report_format('a1')

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="0"/>'
        )

    def test_delete_ultimate(self):
        self.gmp.delete_report_format('a1', ultimate=True)

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="1"/>'
        )

    def test_missing_id(self):
        with self.assertRaises(GvmError):
            self.gmp.delete_report_format(None)

        with self.assertRaises(GvmError):
            self.gmp.delete_report_format('')

    def test_delete_with_type(self):
        self.gmp.delete_report_format(ReportFormatType.SVG)

        report_format_id = get_report_format_id_from_string('svg').value
        self.connection.send.has_been_called_with(
            '<delete_report_format '
            'report_format_id="{}" ultimate="0"/>'.format(report_format_id)
        )

==> python-gvm_21.10.0.orig.tar.gz: python-gvm-21.10.0/tests/protocols/gmpv208/entities/report_formats/test_delete_report_format.py <==
# -*- coding: utf-8 -*-
# Copyright (C) 2018-2021 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gvm.errors import GvmError
from gvm.protocols.gmpv208.entities.report_formats import ReportFormatType


class GmpDeleteReportFormatTestMixin:
    def test_delete(self):
        self.gmp.delete_report_format('a1')

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="0"/>'
        )

    def test_delete_ultimate(self):
        self.gmp.delete_report_format('a1', ultimate=True)

        self.connection.send.has_been_called_with(
            '<delete_report_format report_format_id="a1" ultimate="1"/>'
        )

    def test_missing_id(self):
        with self.assertRaises(GvmError):
            self.gmp.delete_report_format(None)

        with self.assertRaises(GvmError):
            self.gmp.delete_report_format('')

    def test_delete_with_type(self):
        self.gmp.delete_report_format(ReportFormatType.SVG)

        report_format_id = ReportFormatType.from_string('svg').value
        self.connection.send.has_been_called_with(
            '<delete_report_format '
            f'report_format_id="{report_format_id}" ultimate="0"/>'
        )
